@@ -332,7 +332,7 @@ class ReverserServer : public SampleSocketServiceServer
 {
 public:
 	ReverserServer(InetHostAddress & machine, int port) : 
-			SampleSocketServiceServer(machine, port), TCPSocket(machine, port), Thread()
+	TCPSocket(machine, port), Thread(), SampleSocketServiceServer(machine, port)
 	{
 	}
 	virtual ~ReverserServer()
