@@ -30,7 +30,7 @@
 int main(int argc, char **argv)
 {
   cout << "Serial Echo to TCP Sessions" << endl;
-  SerialEcho *modem;
+  SerialEcho *modem = NULL;
   try {
     modem = new SerialEcho("/dev/modem2");
   } catch (SerialEcho::xError *e) {
